@@ -3,24 +3,37 @@ package App::ZofCMS;
 use warnings;
 use strict;
 
-our $VERSION = '0.0225';
+our $VERSION = '1.001001'; # VERSION
 
 
 1;
 __END__
 
+=for stopwords Drupal Wordpress codebase  ssh  dir  foo webpage
+
 =encoding utf8
 
 =head1 NAME
 
 App::ZofCMS - web framework and templating system for small-medium sites.
 
-=head1 SYNOPSYS
+=head1 SYNOPSIS
 
 This module is just the main documentation for ZofCMS framework. See
 L<USING THE FRAMEWORK> section below for explanation of how to use this
 framework.
 
+=head1 WARNING!!!
+
+Do B<NOT> use this framework for production code.
+At worst, this framework will be no longer maintained; at best, it will
+be significantly rewritten, breaking the API. It exists in the current
+state only to support the existing codebase.
+
+=head1 SEE ALSO
+
+L<Dancer>, L<Dancer2>, L<Mojolicious>, and of course, L<Catalyst>
+
 =head1 DESCRIPTION
 
 ZofCMS stands for "Zoffix's Content Management System", however I prefer
@@ -33,7 +46,7 @@ a great framework, not just for web, and it offers far more functionality
 than ZofCMS ever will.
 
 ZofCMS is plugin based. If you create your own plugins, please upload them
-to L<App::ZofCMS::Plugin> namespace or email it to me (L<zoffix@cpan.org>)
+to L<App::ZofCMS::Plugin> namespace or email it to me (C<zoffix@cpan.org>)
 and I will package it, upload it, and give you corresponding credits.
 
 ZofCMS currently uses L<HTML::Template> as a module to interpret HTML
@@ -44,9 +57,9 @@ Despite the "core" of the framework along with all of its plugins being
 on CPAN there is a helper script (C<zofcms_helper>) which can produce
 a ready-for-upload set of files which you can simply upload to your server
 without having to install anything from CPAN on the server itself. See
-L<perldoc zofcms_helper>.
+C<perldoc zofcms_helper>.
 
-=head1 HYSTORY
+=head1 HISTORY
 
 This section does not say anything useful, you can skip it if you are
 not interested in what made me create ZofCMS.
@@ -144,7 +157,7 @@ ZofCMS directory/file setup is arranged to have one directory web
 accessible; that one will contain C<index.pl> along with any CSS/JS files
 or images that will be on your website. Another directory will not be
 web accessible; here you will keep your ZofCMS templates along with page
-templates (i.e. L<HTML::Templates>, or "data") and the config file.
+templates (i.e. L<HTML::Template>, or "data") and the config file.
 
 As example we will want our site to be in C</var/www/testsite/> directory,
 thus we go (assuming we are on the system which has C<mkdir> and C<cd>):
@@ -219,57 +232,29 @@ touch C<base.tmpl> file in your "data directory" you can now access
 your web application and see a page which will display current time.
 How wonderful \o/
 
-=head1 BUG REPORTS AND CONTRIBUTIONS BY
+=head1 REPOSITORY
 
-B<Neil 'NEILB' Bowers> -- Patch to the I<Changes> file to ensure
-compliance with L<CPAN::Changes::Spec>
-
-=head1 AUTHOR
-
-Zoffix Znet, C<< <zoffix at cpan.org> >>
-(L<http://zoffix.com>, L<http://haslayout.net>)
+Fork this module on GitHub:
+L<https://github.com/zoffixznet/App-ZofCMS>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-app-zofcms at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=App-ZofCMS>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+To report bugs or request features, please use
+L<https://github.com/zoffixznet/App-ZofCMS/issues>
 
-=head1 SUPPORT
+If you can't access GitHub, you can email your request
+to C<bug-App-ZofCMS at rt.cpan.org>
 
-You can find documentation for this module with the perldoc command.
+=head1 AUTHOR
 
-    perldoc App::ZofCMS
+Zoffix Znet <zoffix at cpan.org>
+(L<http://zoffix.com/>, L<http://haslayout.net/>)
 
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=App-ZofCMS>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/App-ZofCMS>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/App-ZofCMS>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/App-ZofCMS>
-
-=back
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008 Zoffix Znet, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head1 LICENSE
 
+You can use and distribute this module under the same terms as Perl itself.
+See the C<LICENSE> file included in this distribution for complete
+details.
 
 =cut
 
