@@ -1,21 +1,23 @@
-package App::ZofCMS;
+package App::ZofCMS::Plugin;
 
 use warnings;
 use strict;
 
-our $VERSION = '0.0225';
-
+our $VERSION = '1.001001'; # VERSION
 
 1;
 __END__
 
+=for stopwords ModuleName foo pm tmpl
+
+
 =encoding utf8
 
 =head1 NAME
 
 App::ZofCMS::Plugin - documentation for ZofCMS plugin authors
 
-=head1 SYNOPSYS
+=head1 SYNOPSIS
 
     package App::ZofCMS::Plugins::QueryToTemplate;
 
@@ -26,12 +28,12 @@ App::ZofCMS::Plugin - documentation for ZofCMS plugin authors
 
     sub process {
         my ( $self, $template, $query, $config ) = @_;
-        
+
         keys %$query;
         while ( my ( $key, $value ) = each %$query ) {
             $template->{t}{"query_$key"} = $value;
         }
-        
+
         return;
     }
 
@@ -71,52 +73,29 @@ Normally a plugin would take user input from ZofCMS template hashref.
 If you are using anything outside the C<d> key (as described in
 L<App::ZofCMS::Template> please C<delete()> the key from ZofCMS template.
 
-=head1 AUTHOR
+=head1 REPOSITORY
 
-Zoffix Znet, C<< <zoffix at cpan.org> >>
-(L<http://zoffix.com>, L<http://haslayout.net>)
+Fork this module on GitHub:
+L<https://github.com/zoffixznet/App-ZofCMS>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-app-zofcms at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=App-ZofCMS>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+To report bugs or request features, please use
+L<https://github.com/zoffixznet/App-ZofCMS/issues>
 
-=head1 SUPPORT
+If you can't access GitHub, you can email your request
+to C<bug-App-ZofCMS at rt.cpan.org>
 
-You can find documentation for this module with the perldoc command.
+=head1 AUTHOR
 
-    perldoc App::ZofCMS
+Zoffix Znet <zoffix at cpan.org>
+(L<http://zoffix.com/>, L<http://haslayout.net/>)
 
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=App-ZofCMS>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/App-ZofCMS>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/App-ZofCMS>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/App-ZofCMS>
-
-=back
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008 Zoffix Znet, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head1 LICENSE
 
+You can use and distribute this module under the same terms as Perl itself.
+See the C<LICENSE> file included in this distribution for complete
+details.
 
 =cut
 
